@@ -2,7 +2,7 @@ from dez.http.client import HTTPClientRequest, HTTPClient
 import event
 import time
 
-def main(port):
+def main(**kwargs):
     event.initialize(["pyevent"])
     client = HTTPClient()
     for i in range(20):
@@ -10,7 +10,7 @@ def main(port):
 #        client.get_url("http://www.google.com/", cb=response_cb)
 #        client.get_url("http://www.google.com/", cb=response_cb)
 #        client.get_url("http://www.google.com/", cb=response_cb)
-        client.get_url("http://localhost:"+port+"/", cb=response_cb, cbargs=[i+1])
+        client.get_url("http://"+domain+":"+port+"/", cb=response_cb, cbargs=[i+1])
     event.signal(2, event.abort)
     event.dispatch()
     
